summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/fight.cc
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/fight.cc')
-rw-r--r--crawl-ref/source/fight.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/crawl-ref/source/fight.cc b/crawl-ref/source/fight.cc
index 67c88e6dd1..794e264666 100644
--- a/crawl-ref/source/fight.cc
+++ b/crawl-ref/source/fight.cc
@@ -1044,7 +1044,7 @@ bool melee_attack::player_aux_unarmed()
|| (weapon
&& hands == HANDS_TWO
&& weapon->base_type != OBJ_STAVES
- && weapon->sub_type != WPN_QUARTERSTAFF) )
+ && weapon_skill(*weapon) != SK_STAVES))
{
continue;
}
@@ -3070,10 +3070,10 @@ int melee_attack::player_calc_base_weapon_damage()
if (weapon->base_type == OBJ_WEAPONS || item_is_staff( *weapon ))
damage = property( *weapon, PWPN_DAMAGE );
// Quarterstaves can be wielded with a worn shield, but are much
// less effective.
if (shield && weapon->base_type == OBJ_WEAPONS
- && weapon->sub_type == WPN_QUARTERSTAFF
+ && weapon_skill(*weapon) == SK_STAVES
&& hands_reqd(*weapon, player_size()) == HANDS_HALF)
{
damage /= 2;
@@ -3070,10 +3070,10 @@ int melee_attack::player_calc_base_weapon_damage()
if (weapon->base_type == OBJ_WEAPONS || item_is_staff( *weapon ))
damage = property( *weapon, PWPN_DAMAGE );
- // Quarterstaves can be wielded with a worn shield, but are much
- // less effective.
+ // Staves can be wielded with a worn shield, but are much less
+ // effective.
if (shield && weapon->base_type == OBJ_WEAPONS